FileExtension class

Converts platform picker files into Ensemble file models.

Constructors

FileExtension()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPlatformFile(PlatformFile file) → File
Creates an Ensemble File from a file-picker PlatformFile.